@@ -23,10 +23,14 @@
 #include <endian.h>
 #include <sys/ioctl.h>
 #include <alsa/asoundlib.h>
-#include <sound/hdsp.h>
+#include <alsa/sound/hdsp.h>
 
 static u_int32_t code[24413];
 
+#ifndef RPM
+# define RPM	4
+#endif
+
 int read_bin_file(u_int32_t *array, const char *filename)
 {
 	FILE *out;
@@ -40,16 +44,7 @@ int read_bin_file(u_int32_t *array, const char *filename)
 		return -1;
 	}
 	fclose(out);
-#if __BYTE_ORDER == __BIG_ENDIAN
-	{
-		unsigned int idx;
-		for (idx = 0; idx < 24413; idx++)
-			array[idx] = ((array[idx] & 0x000000ff) << 16) |
-				     ((array[idx] & 0x0000ff00) << 8)  |
-				     ((array[idx] & 0x00ff0000) >> 8)  |
-				     ((array[idx] & 0xff000000) >> 16);
-	}
-#endif
+
 	return 0;
 }
 
@@ -79,7 +74,7 @@ void upload_firmware(int card)
 	return;
     }
 
-    firmware.firmware_data = (unsigned long *)code;
+    firmware.firmware_data = code;
     switch (version.io_type) {
     case Multiface:
 	if (version.firmware_rev == 0xa) {
@@ -95,6 +90,9 @@ void upload_firmware(int card)
 	    err = read_bin_file(code, DATAPATH "/digiface_firmware_rev11.bin");
 	}
 	break;
+    case RPM:
+	err = read_bin_file(code, DATAPATH "/rpm_firmware.bin");
+	break;
     default:
 	fprintf(stderr, "Unknown iobox or firmware revision\n");
 	snd_hwdep_close(hw);
